async fn get_reaction_count(
http: &Http,
message: &Message,
reaction_type: &ReactionType,
) -> u32Expand description
Count users who reacted with a specific emoji, excluding the bot.
async fn get_reaction_count(
http: &Http,
message: &Message,
reaction_type: &ReactionType,
) -> u32Count users who reacted with a specific emoji, excluding the bot.